<?php

namespace Pinpoint\NavLog\Plugin;

use Magento\Framework\App\RequestInterface;
use Magento\Webapi\Controller\Rest;
use Pinpoint\NavLog\Model\Logger\Logger;

/**
 * Class RestApiLog
 * @package Pinpoint\NavLog\Plugin
 */
class RestApiLog
{
    /**
     * @var Logger
     */
    protected Logger $logger;

    /**
     * @var string[]
     */
    protected array $excludedPayloads = [
        '/rest/V1/integration/admin/token',
    ];

    /**
     * RestApiLog constructor.
     * @param Logger $logger
     */
    public function __construct(Logger $logger)
    {
        $this->logger = $logger;
    }

    /**
     * @param \Magento\Webapi\Controller\Rest $subject
     * @param \Magento\Framework\App\RequestInterface $request
     */
    public function beforeDispatch(
        Rest $subject,
        RequestInterface $request
    ) {
        $this->logger->info('SOURCE [REST]: ' . $request->getClientIp());
        $this->logger->info('METHOD: ' . $request->getMethod());
        $this->logger->info('PATH: ' . $request->getPathInfo());

        if (!in_array($request->getPathInfo(), $this->excludedPayloads)) {
            $this->logger->info('CONTENT: ' . $request->getContent());
        } else {
            $this->logger->info('CONTENT: Censored due to calling' . $request->getPathInfo());
        }
    }
}
