<?php

namespace Pinpoint\NavLog\Plugin;

use Magento\Framework\App\RequestInterface;
use Magento\Webapi\Controller\Soap;
use Pinpoint\NavLog\Model\Logger\Logger;

/**
 * Class SoapApiLog
 * @package Pinpoint\NavLog\Plugin
 */
class SoapApiLog
{
    /**
     * @var Logger
     */
    protected Logger $logger;

    /**
     * @var string[]
     */
    protected array $excludedPayloads = [
        'integrationAdminTokenServiceV1',
    ];

    /**
     * RestApiLog constructor.
     * @param Logger $logger
     */
    public function __construct(Logger $logger)
    {
        $this->logger = $logger;
    }

    /**
     * Before dispatch plugin
     * @param \Magento\Webapi\Controller\Soap $subject
     * @param \Magento\Framework\App\RequestInterface $request
     */
    public function beforeDispatch(
        Soap $subject,
        RequestInterface $request
    ): void {
        $this->logger->info('SOURCE [SOAP]: ' . $request->getClientIp());
        $this->logger->info('METHOD: ' . $request->getMethod());
        $this->logger->info('PATH: ' . $request->getPathInfo());

        if (!in_array($request->getParam('services'), $this->excludedPayloads)) {
            $this->logger->info('CONTENT: ' . $request->getContent());
        } else {
            $this->logger->info('CONTENT: Censored due to calling: ' . $request->getParam('services'));
        }
    }
}
